changeset 1815:2b68b6955635

Rename "Koala Paint" to "Koala Painter".
author Matti Hamalainen <ccr@tnsp.org>
date Thu, 21 Jun 2018 19:27:53 +0300
parents 0b7062d874ef
children 8d7b424197bc
files tools/lib64fmts.c
diffstat 1 files changed, 8 insertions(+), 8 deletions(-) [+]
line wrap: on
line diff
--- a/tools/lib64fmts.c	Thu Jun 21 17:22:32 2018 +0300
+++ b/tools/lib64fmts.c	Thu Jun 21 19:27:53 2018 +0300
@@ -10,7 +10,7 @@
 
 
 
-static int fmtProbeKoalaPaintPacked(const DMGrowBuf *buf, const DMC64ImageFormat *fmt)
+static int fmtProbeKoalaPainterPacked(const DMGrowBuf *buf, const DMC64ImageFormat *fmt)
 {
     // Attempt to prevent misprobes of unpacked Koala and Run Paint
     if (buf->len > 30 &&
@@ -23,7 +23,7 @@
 }
 
 
-static int fmtDecodeKoalaPaintPacked(DMC64Image *img, const DMGrowBuf *buf, const DMC64ImageFormat *fmt)
+static int fmtDecodeKoalaPainterPacked(DMC64Image *img, const DMGrowBuf *buf, const DMC64ImageFormat *fmt)
 {
     int res;
     DMGrowBuf mem;
@@ -45,7 +45,7 @@
 }
 
 
-static int fmtEncodeKoalaPaintPacked(DMGrowBuf *buf, const DMC64Image *img, const DMC64ImageFormat *fmt)
+static int fmtEncodeKoalaPainterPacked(DMGrowBuf *buf, const DMC64Image *img, const DMC64ImageFormat *fmt)
 {
     int res;
     DMGrowBuf tmp;
@@ -961,7 +961,7 @@
 //
 DMC64ImageCommonFormat dmC64CommonFormats[] =
 {
-    { // #0: Koala Paint type memory layout
+    { // #0: Koala Painter type memory layout
         D64_FMT_MC,
         C64_SCR_WIDTH / 2, C64_SCR_HEIGHT,
         C64_SCR_CH_WIDTH , C64_SCR_CH_HEIGHT,
@@ -1202,16 +1202,16 @@
     },
 
     {
-        "kla", "Koala Paint (unpacked)", 0x6000, 10003, DM_FMT_RDWR,
+        "kla", "Koala Painter (unpacked)", 0x6000, 10003, DM_FMT_RDWR,
         NULL,
         NULL, NULL,
         { }, &dmC64CommonFormats[0]
     },
 
     {
-        "klp", "Koala Paint (packed)", 0x6000, 0, DM_FMT_RDWR,
-        fmtProbeKoalaPaintPacked,
-        fmtDecodeKoalaPaintPacked, fmtEncodeKoalaPaintPacked,
+        "klp", "Koala Painter (packed)", 0x6000, 0, DM_FMT_RDWR,
+        fmtProbeKoalaPainterPacked,
+        fmtDecodeKoalaPainterPacked, fmtEncodeKoalaPainterPacked,
         { }, &dmC64CommonFormats[0]
     },